"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _Provider = _interopRequireDefault(require("../support/base/Provider"));

var _sequelize = _interopRequireDefault(require("sequelize"));

/**
 * database 服务提供者
 *
 * @author : sunkeysun
 */
class DatabaseProvider extends _Provider.default {
  constructor(...args) {
    super(...args);
    (0, _defineProperty2.default)(this, "staticKey", '$');
  }

  register() {
    const databaseConfig = app().config('database');
    const dbs = {};

    _.each(databaseConfig, (config, dbName) => {
      if (dbName === '$') {
        throw new Error(`database instance name [${this.staticKey}] is not allowed`);
      }

      const {
        driver,
        host,
        port,
        database,
        username,
        password,
        options = {}
      } = config;

      if (!driver) {
        return false;
      }

      const Op = _sequelize.default.Op;
      const realOptions = { ...options,
        dialect: driver,
        host: host,
        port: port,
        freezeTableName: true,
        operatorsAliases: {
          $eq: Op.eq,
          $ne: Op.ne,
          $gte: Op.gte,
          $gt: Op.gt,
          $lte: Op.lte,
          $lt: Op.lt,
          $not: Op.not,
          $in: Op.in,
          $notIn: Op.notIn,
          $is: Op.is,
          $like: Op.like,
          $notLike: Op.notLike,
          $iLike: Op.iLike,
          $notILike: Op.notILike,
          $regexp: Op.regexp,
          $notRegexp: Op.notRegexp,
          $iRegexp: Op.iRegexp,
          $notIRegexp: Op.notIRegexp,
          $between: Op.between,
          $notBetween: Op.notBetween,
          $overlap: Op.overlap,
          $contains: Op.contains,
          $contained: Op.contained,
          $adjacent: Op.adjacent,
          $strictLeft: Op.strictLeft,
          $strictRight: Op.strictRight,
          $noExtendRight: Op.noExtendRight,
          $noExtendLeft: Op.noExtendLeft,
          $and: Op.and,
          $or: Op.or,
          $any: Op.any,
          $all: Op.all,
          $values: Op.values,
          $col: Op.col
        }
      };
      dbs[dbName] = new _sequelize.default(database, username, password, realOptions);
      dbs[dbName].authenticate().then(() => {
        app().logger.info(`database [${dbName}] connect success`, 'database');
        app().emit(app().event('database-connect'), databaseConfig);
      }).catch(e => {
        app().logger.error(`database [${dbName}] connect error : ${e}`, 'database');
        app().emit(app().event('database-error'), e, databaseConfig);
      });
    });

    dbs[this.staticKey] = _sequelize.default;
    return dbs;
  }

}

exports.default = DatabaseProvider;